==> tuia-advert-center-api-1.5.9-20180808.130850-27-sources.jar: cn/com/duiba/tuia/core/api/dto/req/data/FindListParamBaseDto.java <==
package cn.com.duiba.tuia.core.api.dto.req.data;

import cn.com.duiba.tuia.core.api.dto.BaseQueryDateReq;

import java.util.List;

/**
 * Created by zhengjy on 2017/6/17.
 */
public class FindListParamBaseDto  extends BaseQueryDateReq {

    private static final long serialVersionUID = -8848962246172921800L;

    /** 广告名称. */
    private String            advertName;

    /** 广告ID. */
    private Long              advertId;
    /** 广告主id. */
    private Long              companyId;

    /** 广告主名称. */
    private String            companyName;

    /** 广告主邮箱. */
    private String            companyEmail;

    /** 代理商id */
    private Long              agentId;

    /** 代理商名称 */
    private String            agentCompanyName;

    /** 代理商邮箱 */
    private String            agentCompanyEamil;

    /** 广告ID集合. */
    private List<Long> advertIds;


    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getCompanyEmail() {
        return companyEmail;
    }

    public void setCompanyEmail(String companyEmail) {
        this.companyEmail = companyEmail;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public String getAgentCompanyName() {
        return agentCompanyName;
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public String getAgentCompanyEamil() {
        return agentCompanyEamil;
    }

    public void setAgentCompanyEamil(String agentCompanyEamil) {
        this.agentCompanyEamil = agentCompanyEamil;
    }

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }
}

==> tuia-advert-center-api-1.7.4-r-20181016.122044-2-sources.jar: cn/com/duiba/tuia/core/api/dto/req/data/FindListParamBaseDto.java <==
package cn.com.duiba.tuia.core.api.dto.req.data;

import cn.com.duiba.tuia.core.api.dto.BaseQueryDateReq;

import java.util.List;

/**
 * Created by zhengjy on 2017/6/17.
 */
public class FindListParamBaseDto  extends BaseQueryDateReq {

    private static final long serialVersionUID = -8848962246172921800L;

    /** 广告名称. */
    private String            advertName;

    /** 广告ID. */
    private Long              advertId;
    /** 广告主id. */
    private Long              companyId;

    /** 广告主名称. */
    private String            companyName;

    /** 广告主邮箱. */
    private String            companyEmail;

    /** 代理商id */
    private Long              agentId;

    /** 代理商名称 */
    private String            agentCompanyName;

    /** 代理商邮箱 */
    private String            agentCompanyEamil;

    /** 广告ID集合. */
    private List<Long> advertIds;


    public String getAdvertName() {
        return advertName == null ? null : advertName.trim();
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getCompanyName() {
        return companyName == null ? null : companyName.trim();
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getCompanyEmail() {
        return companyEmail == null ? null : companyEmail.trim();
    }

    public void setCompanyEmail(String companyEmail) {
        this.companyEmail = companyEmail;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public String getAgentCompanyName() {
        return agentCompanyName == null ? null : agentCompanyName.trim();
    }

    public void setAgentCompanyName(String agentCompanyName) {
        this.agentCompanyName = agentCompanyName;
    }

    public String getAgentCompanyEamil() {
        return agentCompanyEamil == null ? null : agentCompanyEamil.trim();
    }

    public void setAgentCompanyEamil(String agentCompanyEamil) {
        this.agentCompanyEamil = agentCompanyEamil;
    }

    public List<Long> getAdvertIds() {
        return advertIds;
    }

    public void setAdvertIds(List<Long> advertIds) {
        this.advertIds = advertIds;
    }

    public Long getCompanyId() {
        return companyId;
    }

    public void setCompanyId(Long companyId) {
        this.companyId = companyId;
    }
}
